import{U as s,dA as i,dB as d}from"./index.0f630b70.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cc9e4888-f1d9-47f3-897b-e8a0234c3176",e._sentryDebugIdIdentifier="sentry-dbid-cc9e4888-f1d9-47f3-897b-e8a0234c3176")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:c,RangePicker:o}=i(d),y=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:c,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(c.name,c),e)});export{y as D,r as M,c as Q,o as R,t as W};
//# sourceMappingURL=dayjs.eaa38b6e.js.map
