import{_ as i}from"./Login.vue_vue_type_script_setup_true_lang.a1b5912b.js";import{d as f,eo as _,ea as m,o as l,Y as b,b as y,u as p,a0 as g}from"./index.0f630b70.js";import{u as w}from"./workspaceStore.61224c34.js";import"./Logo.e9eed733.js";import"./string.532e13bb.js";import"./CircularLoading.b256c752.js";import"./index.9404ab63.js";import"./index.6834cc58.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f7419e50-a2fa-4c6c-b175-df262e198647",e._sentryDebugIdIdentifier="sentry-dbid-f7419e50-a2fa-4c6c-b175-df262e198647")}catch{}})();const k={class:"runner"},h=f({__name:"Login",setup(e){const o=_(),r=m(),s=w(),u=async()=>{const{redirect:t,...a}=r.query;if(t){await o.push({path:t,query:a,params:r.params});return}o.push({name:"playerHome",query:a})};return(t,a)=>{var n,c,d;return l(),b("div",k,[y(i,{"logo-url":(c=(n=p(s).state.workspace)==null?void 0:n.logoUrl)!=null?c:void 0,"brand-name":(d=p(s).state.workspace)==null?void 0:d.brandName,onDone:u},null,8,["logo-url","brand-name"])])}}});const S=g(h,[["__scopeId","data-v-a7e3f7bf"]]);export{S as default};
//# sourceMappingURL=Login.de2c55c0.js.map
