.home-container[data-v-060376d1]{width:100%;height:100%;overflow:auto;display:flex;flex-direction:column;align-items:center}.cards-container[data-v-060376d1]{width:fit-content;justify-content:center;align-items:center;padding:80px 0}.form-card[data-v-060376d1]{cursor:pointer;width:100%;background-color:var(--background-color-main)}.form-card[data-v-060376d1]:hover{box-shadow:0 0 10px #0000001a}.form-card.loading[data-v-060376d1]{opacity:.8;pointer-events:none}
