import{k as n,T as a,m as r,P as o,C as d,M as c,s as p,n as s,p as f,q as m,t as u,v as b}from"./index.0f630b70.js";import{s as g,c as y,a as i}from"./workspaceStore.61224c34.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.dbbe703d.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";import"./PlayerConfigProvider.0f52afbf.js";import"./index.9404ab63.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="e8c277b9-ce66-4f90-97fa-5b79d3cb2d7d",t._sentryDebugIdIdentifier="sentry-dbid-e8c277b9-ce66-4f90-97fa-5b79d3cb2d7d")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await g();const t=y(),e=n({render:()=>f(l)});a.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",c),e.component("Message",p),s(e,m),s(e,u),s(e,b)})();
//# sourceMappingURL=player.bf32c772.js.map
