import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.7d96bf27.js";import{d as v,ea as A,eo as x,f as b,o as i,Y as I,b as d,w as a,u as e,c as f,S as p,aG as s,e9 as l,dd as C,d9 as m,bT as N,a as T,da as B,eV as o,a0 as D}from"./index.0f630b70.js";import{u as V}from"./workspaceStore.61224c34.js";import{C as E}from"./Card.2564e781.js";import"./Logo.e9eed733.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";import"./TabPane.e38cb00d.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new R().stack;c&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[c]="6ee3736e-e54d-478a-a7fd-fc75d043c252",r._sentryDebugIdIdentifier="sentry-dbid-6ee3736e-e54d-478a-a7fd-fc75d043c252")}catch{}})();const S={class:"inner-content"},G={class:"card-content"},H=v({__name:"Error",setup(r){const c=A(),g=x(),u=V(),y=b(()=>{var t,_,w;return(w=(t=u.state.workspace)==null?void 0:t.name)!=null?w:(_=u.state.workspace)==null?void 0:_.brandName}),n=b(()=>{const{status:t}=c.params;switch(t){case"404":return{status:t,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:t,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),h=()=>{g.push({name:"playerHome"})};return(t,_)=>(i(),I("div",S,[d(e(C),null,{default:a(()=>[s(l(n.value.title),1)]),_:1}),d(e(m),{class:"message"},{default:a(()=>[s(l(n.value.message),1)]),_:1}),n.value.action?(i(),f(e(N),{key:0,type:"link",onClick:h},{default:a(()=>[s(l(n.value.action),1)]),_:1})):p("",!0),n.value.showAd?(i(),f(e(E),{key:1,bordered:!1,class:"card"},{default:a(()=>[T("div",G,[d(k,{style:{"margin-bottom":"10px"}}),d(e(m),null,{default:a(()=>[s("This page is part of "+l(y.value?`the ${y.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(u).state.workspace?(i(),f(e(m),{key:0},{default:a(()=>[s("Automate your own processes by getting started "),d(e(B),{href:"https://abstra.io"},{default:a(()=>[s("here")]),_:1}),s(".")]),_:1})):p("",!0)])]),_:1})):p("",!0)]))}});const R=D(H,[["__scopeId","data-v-f16a0b67"]]);export{R as default};
//# sourceMappingURL=Error.f0525922.js.map
