import{O as r}from"./workspaceStore.61224c34.js";import{d as l,X as i,o as u,Y as c,b as a,w as o,u as n,aG as d,dd as f,dc as b}from"./index.0f630b70.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6567dbea-e647-4734-a5df-1b6680436c80",e._sentryDebugIdIdentifier="sentry-dbid-6567dbea-e647-4734-a5df-1b6680436c80")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(u(),c("div",null,[a(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.95988d3b.js.map
