import{b as l,ee as f,eD as o}from"./index.0f630b70.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d6474d59-1ca0-40ee-9dc2-8f0893fef63b",e._sentryDebugIdIdentifier="sentry-dbid-d6474d59-1ca0-40ee-9dc2-8f0893fef63b")}catch{}})();function c(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(i){return Object.getOwnPropertyDescriptor(n,i).enumerable}))),r.forEach(function(i){d(e,i,n[i])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var a=function(t,n){var r=c({},t,n.attrs);return l(f,c({},r,{icon:o}),null)};a.displayName="ExclamationCircleOutlined";a.inheritAttrs=!1;const s=a;export{s as E};
//# sourceMappingURL=ExclamationCircleOutlined.b003bf9c.js.map
