import"./App.vue_vue_type_style_index_0_lang.dbbe703d.js";import{_ as c}from"./App.vue_vue_type_style_index_0_lang.dbbe703d.js";import"./workspaceStore.61224c34.js";import"./index.0f630b70.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";import"./PlayerConfigProvider.0f52afbf.js";import"./index.9404ab63.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="23a57c35-2128-466e-bdd5-447e1c9b1726",e._sentryDebugIdIdentifier="sentry-dbid-23a57c35-2128-466e-bdd5-447e1c9b1726")}catch{}})();export{c as default};
//# sourceMappingURL=App.2f42b4a2.js.map
