import{d as a,o as n,Y as s,a as d,$ as r,ed as l,a0 as c}from"./index.0f630b70.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8c30a8c4-4a04-4856-b8bb-0399af6b62a6",e._sentryDebugIdIdentifier="sentry-dbid-8c30a8c4-4a04-4856-b8bb-0399af6b62a6")}catch{}})();const _={class:"content-layout"},u=a({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(n(),s("div",_,[d("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const f=c(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.1036e4eb.js.map
