.toolbar[data-v-0b520c49]{position:absolute;width:fit-content;margin:0 auto;bottom:12px;left:0px;right:0px;border-radius:8px;box-shadow:0 0 5px #0003;background-color:#fff;padding-right:6px}.toolbar .toolbar__item[data-v-0b520c49]{padding:12px;background-color:#fff;border-radius:4px;display:flex;cursor:grab}.toolbar .toolbar__item[data-v-0b520c49]:hover{box-shadow:0 0 5px #0003;transform:rotate(-5deg)}.workflow-container[data-v-4b892353]{height:100%;width:100%;position:relative;transition:background-color .2s}.workflow-container.dragging[data-v-4b892353]{background-color:#fcf6f6}.workflow-container .dragging-node[data-v-4b892353]{display:flex;padding:12px;background-color:#fff;border-radius:4px;box-shadow:0 0 8px #0000004d}
