.content-layout[data-v-6397d501]{overflow:auto;width:100%;height:100%;padding:20px 60px;box-sizing:border-box;display:flex;align-items:center;flex-direction:column}.content-layout .centered-layout[data-v-6397d501]{width:100%;height:100%;max-width:1024px}.content-layout .centered-layout.full-width[data-v-6397d501]{max-width:unset}
