import{d as r,o as d,c as o,w as a,b as f,$ as u,u as s,dh as i,ey as l,eB as c,bT as p}from"./index.0f630b70.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e0f07bb7-83ad-4ae1-99ed-50766d991253",e._sentryDebugIdIdentifier="sentry-dbid-e0f07bb7-83ad-4ae1-99ed-50766d991253")}catch{}})();const y=r({__name:"AbstraButton",setup(e){return(t,n)=>(d(),o(s(p),l(c(t.$attrs)),{default:a(()=>[f(s(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[u(t.$slots,"default")]),_:3})]),_:3},16))}});export{y as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.85b60c0b.js.map
