import{C as t,E as d,K as i,a as c,M as f,c as b,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.2b784445.js";import"./index.0f630b70.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="59681ac7-041c-4e8c-b954-6c4dfb1c75d5",e._sentryDebugIdIdentifier="sentry-dbid-59681ac7-041c-4e8c-b954-6c4dfb1c75d5")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,c as KeyMod,f as MarkerSeverity,b as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.1553787f.js.map
