import{d as t,o,Y as s,b as c,u as d,by as r,a0 as _}from"./index.0f630b70.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="14c24bc4-aaec-4825-8fbf-c5163ec33af0",e._sentryDebugIdIdentifier="sentry-dbid-14c24bc4-aaec-4825-8fbf-c5163ec33af0")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",i,[c(d(r))]))}});const u=_(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.844428d3.js.map
