import{O as r}from"./workspaceStore.61224c34.js";import{d as i,X as l,o as c,Y as u,b as a,w as n,u as o,aG as s,dd as f,dc as b}from"./index.0f630b70.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2ebff395-b9fa-46e7-90b6-0954cda753c2",e._sentryDebugIdIdentifier="sentry-dbid-2ebff395-b9fa-46e7-90b6-0954cda753c2")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,d)=>(c(),u("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.96f12ec4.js.map
