import{P as k}from"./api.a9b631fd.js";import{b as _}from"./workspaceStore.61224c34.js";import{d as w,N as g,O as c,e as v,o as r,Y as h,b as s,w as T,u as e,c as p,S as m,a0 as K}from"./index.0f630b70.js";import{K as S,_ as I,W as P,P as R,b as V}from"./WorkflowView.04789649.js";import{A as b,T as x}from"./TabPane.e38cb00d.js";import"./Card.2564e781.js";import"./fetch.04be8a9e.js";import"./metadata.cfd15460.js";import"./PhBug.vue.4c6c1483.js";import"./PhCheckCircle.vue.9b1e3e50.js";import"./PhKanban.vue.f3963316.js";import"./PhWebhooksLogo.vue.3edd7efd.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";import"./polling.e2209103.js";import"./asyncComputed.2bec113c.js";import"./PhQuestion.vue.5cd37a6e.js";import"./ant-design.7d916c63.js";import"./index.1eaf0cd2.js";import"./index.b8ac1bae.js";import"./index.ecdf0bc9.js";import"./CollapsePanel.4f375646.js";import"./index.9bf9f6e2.js";import"./index.e0287723.js";import"./Badge.ada44968.js";import"./PhArrowCounterClockwise.vue.9318428b.js";import"./Workflow.b4c39f1e.js";import"./validations.d503dc27.js";import"./string.532e13bb.js";import"./uuid.035607ce.js";import"./index.9404ab63.js";import"./workspaces.ffad515d.js";import"./record.f729e500.js";import"./index.4a75ec96.js";import"./PhArrowDown.vue.36042b0c.js";import"./LoadingOutlined.5ed0afbe.js";import"./DeleteOutlined.c6f4d5ac.js";import"./PhDownloadSimple.vue.e40cfd6e.js";import"./utils.65c8b3c8.js";import"./LoadingContainer.844428d3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="906b1231-b61e-4ad7-ae6b-67ab3c63f42a",t._sentryDebugIdIdentifier="sentry-dbid-906b1231-b61e-4ad7-ae6b-67ab3c63f42a")}catch{}})();const W={class:"threads-view"},A=w({__name:"Threads",setup(t){const o=_().authHeaders,d=new k(o),i=new R(o),u=new V(o),y=new g(c.array(c.string()),"kanban-selected-stages"),a=v("kanban");return(B,l)=>(r(),h("div",W,[s(e(x),{activeKey:a.value,"onUpdate:activeKey":l[0]||(l[0]=f=>a.value=f)},{default:T(()=>[s(e(b),{key:"kanban",tab:"Kanban View"}),s(e(b),{key:"table",tab:"Table View"}),s(e(b),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(r(),p(S,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(y),"stage-run-repository":e(u)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),a.value==="table"?(r(),p(I,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),a.value==="workflow"?(r(),p(P,{key:2,"kanban-repository":e(i),"workflow-api":e(d)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=K(A,[["__scopeId","data-v-d6c18c3e"]]);export{ge as default};
//# sourceMappingURL=Threads.87736694.js.map
