import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.7d96bf27.js";import{B as y}from"./BaseLayout.a58db6a0.js";import{d as p,E as b,L as m,a0 as u,a_ as v,a$ as g,o as _,Y as h,a as r,Z as s,ea as w,eo as S,X as L,c as k,w as n,b as i,u as $}from"./index.0f630b70.js";import{u as x}from"./editor.e625b0ce.js";import{b as B}from"./index.cc0715fd.js";import"./Logo.e9eed733.js";import"./workspaceStore.61224c34.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";import"./asyncComputed.2bec113c.js";import"./index.8ce42306.js";import"./Avatar.b0b40f97.js";import"./index.1eaf0cd2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="07b7f39b-df70-4eb8-ad23-fb2bd4ef160a",e._sentryDebugIdIdentifier="sentry-dbid-07b7f39b-df70-4eb8-ad23-fb2bd4ef160a")}catch{}})();const I=p({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=b({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...m(o)}}});const P={class:"v-spinner"};function D(e,o,a,d,c,l){return v((_(),h("div",P,[r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const R=u(I,[["render",D],["__scopeId","data-v-06538001"]]),j={class:"content"},z=p({__name:"ProjectLogin",setup(e){const o=w(),a=S(),d=x();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function l(){const t=o.query["api-key"];if(typeof t=="string")return t}return L(async()=>{const t=l();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(c),a.push({name:"workspace"})}),(t,C)=>(_(),k(y,null,{navbar:n(()=>[i($(B),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[r("div",j,[i(R)])]),_:1}))}});const G=u(z,[["__scopeId","data-v-944edebb"]]);export{G as default};
//# sourceMappingURL=ProjectLogin.3248c064.js.map
