import{d as i,o as p,c as n,w as m,b as s,u as t}from"./index.0f630b70.js";import"./editor.e625b0ce.js";import{W as a}from"./workspaces.ffad515d.js";import{C as f}from"./ContentLayout.1036e4eb.js";import{_ as d,E as c}from"./View.vue_vue_type_script_setup_true_lang.b42320dd.js";import"./workspaceStore.61224c34.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";import"./asyncComputed.2bec113c.js";import"./record.f729e500.js";import"./gateway.50cd3949.js";import"./popupNotifcation.dd76a56c.js";import"./fetch.04be8a9e.js";import"./SaveButton.e457bdbf.js";import"./UnsavedChangesHandler.0cd99ae8.js";import"./ExclamationCircleOutlined.b003bf9c.js";import"./CrudView.408a4461.js";import"./router.0f31f3f1.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.bf268869.js";import"./BookOutlined.89f2a8c6.js";import"./PhDotsThreeVertical.vue.e2e73559.js";import"./Badge.ada44968.js";import"./index.1eaf0cd2.js";import"./polling.e2209103.js";import"./PhPencil.vue.10ddf5aa.js";import"./index.6834cc58.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="351f6920-7fd0-41d4-9265-054c0bb2ff74",o._sentryDebugIdIdentifier="sentry-dbid-351f6920-7fd0-41d4-9265-054c0bb2ff74")}catch{}})();const F=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),n(f,null,{default:m(()=>[s(d,{"env-var-repository":t(r),mode:"editor","file-opener":t(a)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{F as default};
//# sourceMappingURL=EnvVarsEditor.a9011df0.js.map
