import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.b42320dd.js";import{d as i,ea as s,o as a,c as m,u as d}from"./index.0f630b70.js";import"./gateway.50cd3949.js";import"./popupNotifcation.dd76a56c.js";import"./fetch.04be8a9e.js";import"./record.f729e500.js";import"./SaveButton.e457bdbf.js";import"./UnsavedChangesHandler.0cd99ae8.js";import"./ExclamationCircleOutlined.b003bf9c.js";import"./CrudView.408a4461.js";import"./router.0f31f3f1.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.bf268869.js";import"./BookOutlined.89f2a8c6.js";import"./url.90c69b58.js";import"./PhDotsThreeVertical.vue.e2e73559.js";import"./Badge.ada44968.js";import"./index.1eaf0cd2.js";import"./asyncComputed.2bec113c.js";import"./polling.e2209103.js";import"./PhPencil.vue.10ddf5aa.js";import"./index.6834cc58.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="608727f0-eddb-4186-b7a3-ca6f771c2f38",o._sentryDebugIdIdentifier="sentry-dbid-608727f0-eddb-4186-b7a3-ca6f771c2f38")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(c,f)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.52b32972.js.map
