import{a0 as d,o,Y as n,$ as s,a,S as r}from"./index.0f630b70.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="63601e32-e7ac-4ecb-97f2-c0e92b1cd9b1",e._sentryDebugIdIdentifier="sentry-dbid-63601e32-e7ac-4ecb-97f2-c0e92b1cd9b1")}catch{}})();const c={},i={class:"base-layout"},f={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),n("div",i,[s(e.$slots,"sidebar",{},void 0,!0),a("section",f,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const y=d(c,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.a58db6a0.js.map
