import{C as t}from"./gateway.50cd3949.js";import"./index.0f630b70.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="b610519e-b286-4242-b614-cd05c74af8fa",n._sentryDebugIdIdentifier="sentry-dbid-b610519e-b286-4242-b614-cd05c74af8fa")}catch{}})();class i{async create(e){return t.post(`organizations/${e.organizationId}/members`,{email:e.email})}async delete(e){return t.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return t.get(`organizations/${e}/members`)}async get(e,r){return t.get(`organizations/${e}/members/${r}`)}async update(e,r,a){return t.patch(`organizations/${e}/members/${r}`,a)}async fetchTeamOptions(e){return t.get(`organizations/${e}/teams`)}}export{i as M};
//# sourceMappingURL=member.60d3de62.js.map
