.video-container[data-v-7a979853]{position:relative;width:100%;overflow:hidden;padding-top:56.25%}.responsive-iframe[data-v-7a979853]{position:absolute;top:0;left:0;bottom:0;right:0;width:100%;height:100%}
