import{L as a}from"./Logo.e9eed733.js";import{d as t,o as n,c as r,u as d}from"./index.0f630b70.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6ffaad9b-f599-4e70-96af-4963c26d03c1",e._sentryDebugIdIdentifier="sentry-dbid-6ffaad9b-f599-4e70-96af-4963c26d03c1")}catch{}})();const f="/assets/logo.0faadfa2.svg",u=t({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(o,s)=>(n(),r(a,{"image-url":d(f),"brand-name":"Abstra","hide-text":o.hideText,size:o.size},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.7d96bf27.js.map
