import{B as d}from"./BookOutlined.89f2a8c6.js";import{d as c,o as s,c as f,w as o,b as l,u as n,$ as u,Y as b,aG as i,aS as p,bT as y}from"./index.0f630b70.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="851a052d-c4a8-4d42-b3be-23f5b8476d21",t._sentryDebugIdIdentifier="sentry-dbid-851a052d-c4a8-4d42-b3be-23f5b8476d21")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var a;return s(),f(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[l(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(s(),b(p,{key:1},[i("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.bf268869.js.map
