import{d as h,eo as A,r as B,u as e,o as s,c as i,by as C,Y as f,b as a,w as t,aG as r,bT as c,a as m,dc as w,e9 as _,cO as N,ej as I,eb as L,f0 as S,aS as g,S as D,$ as z,a0 as R}from"./index.0f630b70.js";import{a as $}from"./asyncComputed.2bec113c.js";import{G as T}from"./PhChats.vue.5994232f.js";import{F as V}from"./PhSignOut.vue.8e112f6f.js";import{C as j}from"./router.0f31f3f1.js";import{a as k}from"./gateway.50cd3949.js";import{A as E}from"./index.1eaf0cd2.js";import{A as F}from"./Avatar.b0b40f97.js";import{B as G,A as O,b as P}from"./index.cc0715fd.js";import{B as q}from"./BookOutlined.89f2a8c6.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[o]="9ff1bf2f-acc1-4c83-996c-905212c861ac",n._sentryDebugIdIdentifier="sentry-dbid-9ff1bf2f-acc1-4c83-996c-905212c861ac")}catch{}})();const H={key:1,style:{display:"flex","align-items":"center",gap:"16px"}},M={style:{display:"flex","flex-direction":"column",gap:"10px"}},U={style:{display:"flex",gap:"5px"}},Y=h({__name:"LoginBlock",setup(n){function o(y){const b=y.split("@")[0];return I.exports.kebabCase(b).toUpperCase().split("-").slice(0,2).map(p=>p[0]).join("")}const d=A(),{result:l,loading:u,refetch:x}=$(async()=>k.getAuthor());function v(){k.removeAuthor(),j.shutdown(),x(),d.push({name:"login"})}return(y,b)=>{const p=B("RouterLink");return e(u)?(s(),i(e(C),{key:0})):e(l)?(s(),f("div",H,[a(e(c),{class:"intercom-launcher",target:"_blank",type:"link",size:"small",style:{color:"#d14056",display:"flex","align-items":"center",gap:"6px"}},{icon:t(()=>[a(e(T),{size:18})]),default:t(()=>[r(" Support ")]),_:1}),a(e(N),{placement:"bottomRight"},{content:t(()=>[m("div",M,[a(e(w),{size:"small",type:"secondary"},{default:t(()=>[r(_(e(l).claims.email),1)]),_:1}),a(e(c),{type:"text",onClick:v},{default:t(()=>[m("div",U,[a(e(V),{size:"20"}),r(" Logout ")])]),_:1})])]),default:t(()=>[a(e(E),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(F),{shape:"square"},{default:t(()=>[r(_(o(e(l).claims.email)),1)]),_:1})]),_:1})]),_:1})])):(s(),i(e(c),{key:2},{default:t(()=>[a(p,{to:"/login"},{default:t(()=>[r("Login")]),_:1})]),_:1}))}}}),J={class:"extra"},K=h({__name:"Navbar",props:{breadcrumb:{}},setup(n){return(o,d)=>(s(),i(e(P),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[o.breadcrumb?(s(),i(e(G),{key:0},{default:t(()=>[(s(!0),f(g,null,L(o.breadcrumb,(l,u)=>(s(),i(e(O),{key:u},{default:t(()=>[a(e(S),{to:l.path},{default:t(()=>[r(_(l.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):D("",!0)]),extra:t(()=>[m("div",J,[a(e(c),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[a(e(q))]),default:t(()=>[o.$slots.default?z(o.$slots,"default",{key:0},void 0,!0):(s(),f(g,{key:1},[r("Docs")],64))]),_:3}),a(Y)])]),_:3}))}});const ne=R(K,[["__scopeId","data-v-5ef7b378"]]);export{ne as N};
//# sourceMappingURL=Navbar.4b6eb851.js.map
