import{d as l,eh as c,f as r,o as t,Y as a,S as d,e9 as _,a0 as g}from"./index.0f630b70.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ea33f887-be79-4e53-9380-84ecfa024b6f",e._sentryDebugIdIdentifier="sentry-dbid-ea33f887-be79-4e53-9380-84ecfa024b6f")}catch{}})();const p={class:"logo"},f=["src","alt"],u={key:1},m=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const o=e;c(s=>({"4352941e":n.value}));const n=r(()=>o.size==="large"?"80px":"50px"),i=r(()=>`${o.brandName} Logo`);return(s,y)=>(t(),a("div",p,[s.imageUrl?(t(),a("img",{key:0,class:"logo-img",src:s.imageUrl,alt:i.value},null,8,f)):d("",!0),s.hideText?d("",!0):(t(),a("span",u,_(s.brandName),1))]))}});const h=g(m,[["__scopeId","data-v-16688d14"]]);export{h as L};
//# sourceMappingURL=Logo.e9eed733.js.map
