import{E as c}from"./api.a9b631fd.js";import{C as y}from"./ContentLayout.1036e4eb.js";import{d as w,N as g,O as b,e as _,o as a,c as i,w as l,b as n,u as o,S as s}from"./index.0f630b70.js";import{K as v,_ as K,W as E,E as R,a as T}from"./WorkflowView.04789649.js";import{A as p,T as V}from"./TabPane.e38cb00d.js";import"./fetch.04be8a9e.js";import"./metadata.cfd15460.js";import"./PhBug.vue.4c6c1483.js";import"./PhCheckCircle.vue.9b1e3e50.js";import"./PhKanban.vue.f3963316.js";import"./PhWebhooksLogo.vue.3edd7efd.js";import"./polling.e2209103.js";import"./asyncComputed.2bec113c.js";import"./PhQuestion.vue.5cd37a6e.js";import"./ant-design.7d916c63.js";import"./index.1eaf0cd2.js";import"./index.b8ac1bae.js";import"./index.ecdf0bc9.js";import"./CollapsePanel.4f375646.js";import"./index.9bf9f6e2.js";import"./index.e0287723.js";import"./Badge.ada44968.js";import"./PhArrowCounterClockwise.vue.9318428b.js";import"./Workflow.b4c39f1e.js";import"./validations.d503dc27.js";import"./string.532e13bb.js";import"./uuid.035607ce.js";import"./index.9404ab63.js";import"./workspaces.ffad515d.js";import"./workspaceStore.61224c34.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";import"./record.f729e500.js";import"./index.4a75ec96.js";import"./PhArrowDown.vue.36042b0c.js";import"./Card.2564e781.js";import"./LoadingOutlined.5ed0afbe.js";import"./DeleteOutlined.c6f4d5ac.js";import"./PhDownloadSimple.vue.e40cfd6e.js";import"./utils.65c8b3c8.js";import"./LoadingContainer.844428d3.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="dd88c2ed-82b3-4049-9e7c-fdf5d4c1b8c1",r._sentryDebugIdIdentifier="sentry-dbid-dd88c2ed-82b3-4049-9e7c-fdf5d4c1b8c1")}catch{}})();const co=w({__name:"WorkflowThreads",setup(r){const t=new R,m=new T,f=new g(b.array(b.string()),"kanban-selected-stages"),u=new c,e=_("kanban");return(W,d)=>(a(),i(y,{"full-width":""},{default:l(()=>[n(o(V),{activeKey:e.value,"onUpdate:activeKey":d[0]||(d[0]=k=>e.value=k)},{default:l(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),e.value==="kanban"?(a(),i(v,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(f),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),e.value==="table"?(a(),i(K,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),e.value==="workflow"?(a(),i(E,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{co as default};
//# sourceMappingURL=WorkflowThreads.80d7801e.js.map
