import{P as f}from"./PlayerNavbar.936be03d.js";import{d as g,eo as h,ea as c,e as y,f as b,r as k,o as i,Y as v,u as a,c as w,S as L,a as C,b as I,a0 as N}from"./index.0f630b70.js";import{u as V}from"./workspaceStore.61224c34.js";import"./metadata.cfd15460.js";import"./PhBug.vue.4c6c1483.js";import"./PhCheckCircle.vue.9b1e3e50.js";import"./PhKanban.vue.f3963316.js";import"./PhWebhooksLogo.vue.3edd7efd.js";import"./LoadingOutlined.5ed0afbe.js";import"./PhSignOut.vue.8e112f6f.js";import"./index.8ce42306.js";import"./Avatar.b0b40f97.js";import"./url.90c69b58.js";import"./colorHelpers.13000dc5.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="124cde0a-e3dc-4eb2-8c16-97122351f340",o._sentryDebugIdIdentifier="sentry-dbid-124cde0a-e3dc-4eb2-8c16-97122351f340")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,n=y(null),u=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(d),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const H=N(D,[["__scopeId","data-v-f095bece"]]);export{H as default};
//# sourceMappingURL=Main.c019a1f8.js.map
