import{b as r,u as n}from"./workspaceStore.61224c34.js";import{W as c}from"./PlayerConfigProvider.0f52afbf.js";import{d as f,g as i,r as p,u as o,o as u,c as d,w as l,S as _,b as m}from"./index.0f630b70.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="c460be5f-554a-4872-9cf2-5271c45f3251",t._sentryDebugIdIdentifier="sentry-dbid-c460be5f-554a-4872-9cf2-5271c45f3251")}catch{}})();const h=f({__name:"App",setup(t){const a=r(),e=n();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(w,y)=>{const s=p("RouterView");return o(e).state.workspace?(u(),d(c,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:l(()=>[m(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):_("",!0)}}});export{h as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.dbbe703d.js.map
